# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class PluginsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_plugin(self, **kwargs):
        """
        Delete a plugin
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_plugin(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the plugin (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_plugin_with_http_info(**kwargs)
        else:
            (data) = self.delete_plugin_with_http_info(**kwargs)
            return data

    def delete_plugin_with_http_info(self, **kwargs):
        """
        Delete a plugin
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_plugin_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the plugin (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_plugin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_plugin`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/plugins/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_file(self, **kwargs):
        """
        Get a plugin file
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_file(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the plugin (required)
        :param str file_name: The name of the file from the plugin (required)
        :return: bytes
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytes
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_file_with_http_info(**kwargs)
        else:
            (data) = self.get_file_with_http_info(**kwargs)
            return data

    def get_file_with_http_info(self, **kwargs):
        """
        Get a plugin file
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_file_with_http_info(id=id_value, file_name=file_name_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the plugin (required)
        :param str file_name: The name of the file from the plugin (required)
        :return: bytes
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytes
        """

        all_params = ['id', 'file_name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_file`")
        # verify the required parameter 'file_name' is set
        if ('file_name' not in params) or (params['file_name'] is None):
            raise ValueError("Missing the required parameter `file_name` when calling `get_file`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'file_name' in params:
            path_params['fileName'] = params['file_name']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/plugins/{id}/files/{fileName}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'bytes'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_plugins(self, **kwargs):
        """
        Get a collection of plugins
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_plugins(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name_search: Search text by which to filter plugins' names.
        :param str identifier_search: Search text by which to filter plugins' identifiers.
        :param str category_search: Search text by which to filter plugins' categories.
        :param str sort_order: A field by which to order the plugins followed by a space and 'asc' or 'desc'. Field name can be one of: name, identifier, category
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool include_archived: Whether archived plugins should be included
        :return: PluginOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PluginOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_plugins_with_http_info(**kwargs)
        else:
            (data) = self.get_plugins_with_http_info(**kwargs)
            return data

    def get_plugins_with_http_info(self, **kwargs):
        """
        Get a collection of plugins
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_plugins_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name_search: Search text by which to filter plugins' names.
        :param str identifier_search: Search text by which to filter plugins' identifiers.
        :param str category_search: Search text by which to filter plugins' categories.
        :param str sort_order: A field by which to order the plugins followed by a space and 'asc' or 'desc'. Field name can be one of: name, identifier, category
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool include_archived: Whether archived plugins should be included
        :return: PluginOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PluginOutputListV1
        """

        all_params = ['name_search', 'identifier_search', 'category_search', 'sort_order', 'offset', 'limit', 'include_archived']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plugins" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'identifier_search' in params:
            query_params.append(('identifierSearch', params['identifier_search']))
        if 'category_search' in params:
            query_params.append(('categorySearch', params['category_search']))
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'include_archived' in params:
            query_params.append(('includeArchived', params['include_archived']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/plugins', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'PluginOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def upload_plugin(self, **kwargs):
        """
        Upload a plugin
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_plugin(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :param bool in_development: Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users. Non-administrators may only install Plugins in Development Mode.
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.upload_plugin_with_http_info(**kwargs)
        else:
            (data) = self.upload_plugin_with_http_info(**kwargs)
            return data

    def upload_plugin_with_http_info(self, **kwargs):
        """
        Upload a plugin
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.upload_plugin_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :param bool in_development: Whether this item is in Development Mode, meaning that it is not allowed to be shared with any other users. Non-administrators may only install Plugins in Development Mode.
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['file', 'in_development']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_plugin" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'in_development' in params:
            query_params.append(('inDevelopment', params['in_development']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/plugins', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class NotificationConfigurationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bcc_email_recipients': 'list[EmailNotificationRecipientOutputV1]',
        'capsule_grouping': 'str',
        'capsule_properties': 'list[str]',
        'cc_email_recipients': 'list[EmailNotificationRecipientOutputV1]',
        'contextual_text': 'str',
        'reply_to_email_recipients': 'list[EmailNotificationRecipientOutputV1]',
        'report_format': 'str',
        'subject': 'str',
        'timezone': 'str',
        'to_email_recipients': 'list[EmailNotificationRecipientOutputV1]'
    }

    attribute_map = {
        'bcc_email_recipients': 'bccEmailRecipients',
        'capsule_grouping': 'capsuleGrouping',
        'capsule_properties': 'capsuleProperties',
        'cc_email_recipients': 'ccEmailRecipients',
        'contextual_text': 'contextualText',
        'reply_to_email_recipients': 'replyToEmailRecipients',
        'report_format': 'reportFormat',
        'subject': 'subject',
        'timezone': 'timezone',
        'to_email_recipients': 'toEmailRecipients'
    }

    def __init__(self, bcc_email_recipients=None, capsule_grouping=None, capsule_properties=None, cc_email_recipients=None, contextual_text=None, reply_to_email_recipients=None, report_format=None, subject=None, timezone=None, to_email_recipients=None):
        """
        NotificationConfigurationOutputV1 - a model defined in Swagger
        """

        self._bcc_email_recipients = None
        self._capsule_grouping = None
        self._capsule_properties = None
        self._cc_email_recipients = None
        self._contextual_text = None
        self._reply_to_email_recipients = None
        self._report_format = None
        self._subject = None
        self._timezone = None
        self._to_email_recipients = None

        if bcc_email_recipients is not None:
          self.bcc_email_recipients = bcc_email_recipients
        if capsule_grouping is not None:
          self.capsule_grouping = capsule_grouping
        if capsule_properties is not None:
          self.capsule_properties = capsule_properties
        if cc_email_recipients is not None:
          self.cc_email_recipients = cc_email_recipients
        if contextual_text is not None:
          self.contextual_text = contextual_text
        if reply_to_email_recipients is not None:
          self.reply_to_email_recipients = reply_to_email_recipients
        if report_format is not None:
          self.report_format = report_format
        if subject is not None:
          self.subject = subject
        if timezone is not None:
          self.timezone = timezone
        if to_email_recipients is not None:
          self.to_email_recipients = to_email_recipients

    @property
    def bcc_email_recipients(self):
        """
        Gets the bcc_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Bcc list of the email

        :return: The bcc_email_recipients of this NotificationConfigurationOutputV1.
        :rtype: list[EmailNotificationRecipientOutputV1]
        """
        return self._bcc_email_recipients

    @bcc_email_recipients.setter
    def bcc_email_recipients(self, bcc_email_recipients):
        """
        Sets the bcc_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Bcc list of the email

        :param bcc_email_recipients: The bcc_email_recipients of this NotificationConfigurationOutputV1.
        :type: list[EmailNotificationRecipientOutputV1]
        """
        if bcc_email_recipients is None:
            raise ValueError("Invalid value for `bcc_email_recipients`, must not be `None`")

        self._bcc_email_recipients = bcc_email_recipients

    @property
    def capsule_grouping(self):
        """
        Gets the capsule_grouping of this NotificationConfigurationOutputV1.
        The format in which capsules are grouped in the notification

        :return: The capsule_grouping of this NotificationConfigurationOutputV1.
        :rtype: str
        """
        return self._capsule_grouping

    @capsule_grouping.setter
    def capsule_grouping(self, capsule_grouping):
        """
        Sets the capsule_grouping of this NotificationConfigurationOutputV1.
        The format in which capsules are grouped in the notification

        :param capsule_grouping: The capsule_grouping of this NotificationConfigurationOutputV1.
        :type: str
        """

        self._capsule_grouping = capsule_grouping

    @property
    def capsule_properties(self):
        """
        Gets the capsule_properties of this NotificationConfigurationOutputV1.
        The list of properties included in the notification

        :return: The capsule_properties of this NotificationConfigurationOutputV1.
        :rtype: list[str]
        """
        return self._capsule_properties

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties):
        """
        Sets the capsule_properties of this NotificationConfigurationOutputV1.
        The list of properties included in the notification

        :param capsule_properties: The capsule_properties of this NotificationConfigurationOutputV1.
        :type: list[str]
        """
        if capsule_properties is None:
            raise ValueError("Invalid value for `capsule_properties`, must not be `None`")

        self._capsule_properties = capsule_properties

    @property
    def cc_email_recipients(self):
        """
        Gets the cc_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Cc list of the email

        :return: The cc_email_recipients of this NotificationConfigurationOutputV1.
        :rtype: list[EmailNotificationRecipientOutputV1]
        """
        return self._cc_email_recipients

    @cc_email_recipients.setter
    def cc_email_recipients(self, cc_email_recipients):
        """
        Sets the cc_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Cc list of the email

        :param cc_email_recipients: The cc_email_recipients of this NotificationConfigurationOutputV1.
        :type: list[EmailNotificationRecipientOutputV1]
        """
        if cc_email_recipients is None:
            raise ValueError("Invalid value for `cc_email_recipients`, must not be `None`")

        self._cc_email_recipients = cc_email_recipients

    @property
    def contextual_text(self):
        """
        Gets the contextual_text of this NotificationConfigurationOutputV1.
        Text that provides additional context in the notification

        :return: The contextual_text of this NotificationConfigurationOutputV1.
        :rtype: str
        """
        return self._contextual_text

    @contextual_text.setter
    def contextual_text(self, contextual_text):
        """
        Sets the contextual_text of this NotificationConfigurationOutputV1.
        Text that provides additional context in the notification

        :param contextual_text: The contextual_text of this NotificationConfigurationOutputV1.
        :type: str
        """

        self._contextual_text = contextual_text

    @property
    def reply_to_email_recipients(self):
        """
        Gets the reply_to_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Reply-To list of the email

        :return: The reply_to_email_recipients of this NotificationConfigurationOutputV1.
        :rtype: list[EmailNotificationRecipientOutputV1]
        """
        return self._reply_to_email_recipients

    @reply_to_email_recipients.setter
    def reply_to_email_recipients(self, reply_to_email_recipients):
        """
        Sets the reply_to_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the Reply-To list of the email

        :param reply_to_email_recipients: The reply_to_email_recipients of this NotificationConfigurationOutputV1.
        :type: list[EmailNotificationRecipientOutputV1]
        """
        if reply_to_email_recipients is None:
            raise ValueError("Invalid value for `reply_to_email_recipients`, must not be `None`")

        self._reply_to_email_recipients = reply_to_email_recipients

    @property
    def report_format(self):
        """
        Gets the report_format of this NotificationConfigurationOutputV1.
        The format of the report in the notification

        :return: The report_format of this NotificationConfigurationOutputV1.
        :rtype: str
        """
        return self._report_format

    @report_format.setter
    def report_format(self, report_format):
        """
        Sets the report_format of this NotificationConfigurationOutputV1.
        The format of the report in the notification

        :param report_format: The report_format of this NotificationConfigurationOutputV1.
        :type: str
        """

        self._report_format = report_format

    @property
    def subject(self):
        """
        Gets the subject of this NotificationConfigurationOutputV1.
        Subject for the notification email

        :return: The subject of this NotificationConfigurationOutputV1.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this NotificationConfigurationOutputV1.
        Subject for the notification email

        :param subject: The subject of this NotificationConfigurationOutputV1.
        :type: str
        """

        self._subject = subject

    @property
    def timezone(self):
        """
        Gets the timezone of this NotificationConfigurationOutputV1.
        The IANA timezone used for formatting the start and end times of capsules, defaults to UTC

        :return: The timezone of this NotificationConfigurationOutputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this NotificationConfigurationOutputV1.
        The IANA timezone used for formatting the start and end times of capsules, defaults to UTC

        :param timezone: The timezone of this NotificationConfigurationOutputV1.
        :type: str
        """

        self._timezone = timezone

    @property
    def to_email_recipients(self):
        """
        Gets the to_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the To list of the email

        :return: The to_email_recipients of this NotificationConfigurationOutputV1.
        :rtype: list[EmailNotificationRecipientOutputV1]
        """
        return self._to_email_recipients

    @to_email_recipients.setter
    def to_email_recipients(self, to_email_recipients):
        """
        Sets the to_email_recipients of this NotificationConfigurationOutputV1.
        Email addresses or User IDs that will be in the To list of the email

        :param to_email_recipients: The to_email_recipients of this NotificationConfigurationOutputV1.
        :type: list[EmailNotificationRecipientOutputV1]
        """
        if to_email_recipients is None:
            raise ValueError("Invalid value for `to_email_recipients`, must not be `None`")

        self._to_email_recipients = to_email_recipients

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NotificationConfigurationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filter': 'str',
        'archived': 'bool',
        'background_color': 'str',
        'columns': 'int',
        'created_at': 'str',
        'description': 'str',
        'enabled': 'bool',
        'end_date': 'str',
        'filters': 'list[BoardFilterOutputV1]',
        'id': 'str',
        'locked': 'bool',
        'name': 'str',
        'row_height': 'int',
        'scoped_to': 'str',
        'start_date': 'str',
        'tiles': 'list[TileOutputV1]',
        'updated_at': 'str'
    }

    attribute_map = {
        'applied_filter': 'appliedFilter',
        'archived': 'archived',
        'background_color': 'backgroundColor',
        'columns': 'columns',
        'created_at': 'createdAt',
        'description': 'description',
        'enabled': 'enabled',
        'end_date': 'endDate',
        'filters': 'filters',
        'id': 'id',
        'locked': 'locked',
        'name': 'name',
        'row_height': 'rowHeight',
        'scoped_to': 'scopedTo',
        'start_date': 'startDate',
        'tiles': 'tiles',
        'updated_at': 'updatedAt'
    }

    def __init__(self, applied_filter=None, archived=None, background_color=None, columns=None, created_at=None, description=None, enabled=None, end_date=None, filters=None, id=None, locked=None, name=None, row_height=None, scoped_to=None, start_date=None, tiles=None, updated_at=None):
        """
        BoardOutputV1 - a model defined in Swagger
        """

        self._applied_filter = None
        self._archived = None
        self._background_color = None
        self._columns = None
        self._created_at = None
        self._description = None
        self._enabled = None
        self._end_date = None
        self._filters = None
        self._id = None
        self._locked = None
        self._name = None
        self._row_height = None
        self._scoped_to = None
        self._start_date = None
        self._tiles = None
        self._updated_at = None

        if applied_filter is not None:
          self.applied_filter = applied_filter
        if archived is not None:
          self.archived = archived
        if background_color is not None:
          self.background_color = background_color
        if columns is not None:
          self.columns = columns
        if created_at is not None:
          self.created_at = created_at
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if end_date is not None:
          self.end_date = end_date
        if filters is not None:
          self.filters = filters
        if id is not None:
          self.id = id
        if locked is not None:
          self.locked = locked
        if name is not None:
          self.name = name
        if row_height is not None:
          self.row_height = row_height
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if start_date is not None:
          self.start_date = start_date
        if tiles is not None:
          self.tiles = tiles
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def applied_filter(self):
        """
        Gets the applied_filter of this BoardOutputV1.
        The applied filter configuration

        :return: The applied_filter of this BoardOutputV1.
        :rtype: str
        """
        return self._applied_filter

    @applied_filter.setter
    def applied_filter(self, applied_filter):
        """
        Sets the applied_filter of this BoardOutputV1.
        The applied filter configuration

        :param applied_filter: The applied_filter of this BoardOutputV1.
        :type: str
        """

        self._applied_filter = applied_filter

    @property
    def archived(self):
        """
        Gets the archived of this BoardOutputV1.
        Whether the board is archived

        :return: The archived of this BoardOutputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this BoardOutputV1.
        Whether the board is archived

        :param archived: The archived of this BoardOutputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def background_color(self):
        """
        Gets the background_color of this BoardOutputV1.
        The background color of the board

        :return: The background_color of this BoardOutputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this BoardOutputV1.
        The background color of the board

        :param background_color: The background_color of this BoardOutputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def columns(self):
        """
        Gets the columns of this BoardOutputV1.
        The number of columns in the board grid

        :return: The columns of this BoardOutputV1.
        :rtype: int
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this BoardOutputV1.
        The number of columns in the board grid

        :param columns: The columns of this BoardOutputV1.
        :type: int
        """
        if columns is None:
            raise ValueError("Invalid value for `columns`, must not be `None`")

        self._columns = columns

    @property
    def created_at(self):
        """
        Gets the created_at of this BoardOutputV1.
        The time the board was created

        :return: The created_at of this BoardOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this BoardOutputV1.
        The time the board was created

        :param created_at: The created_at of this BoardOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def description(self):
        """
        Gets the description of this BoardOutputV1.
        The description of the board

        :return: The description of this BoardOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BoardOutputV1.
        The description of the board

        :param description: The description of this BoardOutputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this BoardOutputV1.
        Whether the board is enabled

        :return: The enabled of this BoardOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this BoardOutputV1.
        Whether the board is enabled

        :param enabled: The enabled of this BoardOutputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def end_date(self):
        """
        Gets the end_date of this BoardOutputV1.
        The end date for the date range of the data

        :return: The end_date of this BoardOutputV1.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BoardOutputV1.
        The end date for the date range of the data

        :param end_date: The end_date of this BoardOutputV1.
        :type: str
        """

        self._end_date = end_date

    @property
    def filters(self):
        """
        Gets the filters of this BoardOutputV1.
        Filters configured on this board

        :return: The filters of this BoardOutputV1.
        :rtype: list[BoardFilterOutputV1]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this BoardOutputV1.
        Filters configured on this board

        :param filters: The filters of this BoardOutputV1.
        :type: list[BoardFilterOutputV1]
        """
        if filters is None:
            raise ValueError("Invalid value for `filters`, must not be `None`")

        self._filters = filters

    @property
    def id(self):
        """
        Gets the id of this BoardOutputV1.
        The unique identifier of the board

        :return: The id of this BoardOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BoardOutputV1.
        The unique identifier of the board

        :param id: The id of this BoardOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def locked(self):
        """
        Gets the locked of this BoardOutputV1.
        Whether the board is locked

        :return: The locked of this BoardOutputV1.
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """
        Sets the locked of this BoardOutputV1.
        Whether the board is locked

        :param locked: The locked of this BoardOutputV1.
        :type: bool
        """

        self._locked = locked

    @property
    def name(self):
        """
        Gets the name of this BoardOutputV1.
        The name of the board

        :return: The name of this BoardOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BoardOutputV1.
        The name of the board

        :param name: The name of this BoardOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def row_height(self):
        """
        Gets the row_height of this BoardOutputV1.
        The height of each row in grid units

        :return: The row_height of this BoardOutputV1.
        :rtype: int
        """
        return self._row_height

    @row_height.setter
    def row_height(self, row_height):
        """
        Sets the row_height of this BoardOutputV1.
        The height of each row in grid units

        :param row_height: The row_height of this BoardOutputV1.
        :type: int
        """
        if row_height is None:
            raise ValueError("Invalid value for `row_height`, must not be `None`")

        self._row_height = row_height

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this BoardOutputV1.
        The ID of the workbook this board is scoped to

        :return: The scoped_to of this BoardOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this BoardOutputV1.
        The ID of the workbook this board is scoped to

        :param scoped_to: The scoped_to of this BoardOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def start_date(self):
        """
        Gets the start_date of this BoardOutputV1.
        The start date for the date range of the data

        :return: The start_date of this BoardOutputV1.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BoardOutputV1.
        The start date for the date range of the data

        :param start_date: The start_date of this BoardOutputV1.
        :type: str
        """

        self._start_date = start_date

    @property
    def tiles(self):
        """
        Gets the tiles of this BoardOutputV1.
        The tiles on this board

        :return: The tiles of this BoardOutputV1.
        :rtype: list[TileOutputV1]
        """
        return self._tiles

    @tiles.setter
    def tiles(self, tiles):
        """
        Sets the tiles of this BoardOutputV1.
        The tiles on this board

        :param tiles: The tiles of this BoardOutputV1.
        :type: list[TileOutputV1]
        """
        if tiles is None:
            raise ValueError("Invalid value for `tiles`, must not be `None`")

        self._tiles = tiles

    @property
    def updated_at(self):
        """
        Gets the updated_at of this BoardOutputV1.
        The last time this board was updated

        :return: The updated_at of this BoardOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this BoardOutputV1.
        The last time this board was updated

        :param updated_at: The updated_at of this BoardOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class VersionSourceItemOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_item_id': 'str',
        'source_item_name': 'str',
        'source_item_type': 'str'
    }

    attribute_map = {
        'source_item_id': 'sourceItemId',
        'source_item_name': 'sourceItemName',
        'source_item_type': 'sourceItemType'
    }

    def __init__(self, source_item_id=None, source_item_name=None, source_item_type=None):
        """
        VersionSourceItemOutputV1 - a model defined in Swagger
        """

        self._source_item_id = None
        self._source_item_name = None
        self._source_item_type = None

        if source_item_id is not None:
          self.source_item_id = source_item_id
        if source_item_name is not None:
          self.source_item_name = source_item_name
        if source_item_type is not None:
          self.source_item_type = source_item_type

    @property
    def source_item_id(self):
        """
        Gets the source_item_id of this VersionSourceItemOutputV1.
        The source item ID for this version

        :return: The source_item_id of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_id

    @source_item_id.setter
    def source_item_id(self, source_item_id):
        """
        Sets the source_item_id of this VersionSourceItemOutputV1.
        The source item ID for this version

        :param source_item_id: The source_item_id of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_id is None:
            raise ValueError("Invalid value for `source_item_id`, must not be `None`")

        self._source_item_id = source_item_id

    @property
    def source_item_name(self):
        """
        Gets the source_item_name of this VersionSourceItemOutputV1.
        The source item name for this version

        :return: The source_item_name of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_name

    @source_item_name.setter
    def source_item_name(self, source_item_name):
        """
        Sets the source_item_name of this VersionSourceItemOutputV1.
        The source item name for this version

        :param source_item_name: The source_item_name of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_name is None:
            raise ValueError("Invalid value for `source_item_name`, must not be `None`")

        self._source_item_name = source_item_name

    @property
    def source_item_type(self):
        """
        Gets the source_item_type of this VersionSourceItemOutputV1.
        The source item type for this version

        :return: The source_item_type of this VersionSourceItemOutputV1.
        :rtype: str
        """
        return self._source_item_type

    @source_item_type.setter
    def source_item_type(self, source_item_type):
        """
        Sets the source_item_type of this VersionSourceItemOutputV1.
        The source item type for this version

        :param source_item_type: The source_item_type of this VersionSourceItemOutputV1.
        :type: str
        """
        if source_item_type is None:
            raise ValueError("Invalid value for `source_item_type`, must not be `None`")

        self._source_item_type = source_item_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VersionSourceItemOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import annotations

import setuptools

# Metadata is defined in pyproject.toml [project] section to prevent Dynamic fields
# This setup.py only handles package discovery and build configuration
# When pyproject.toml [project] section exists, setuptools will use it instead of setup.py metadata
setuptools.setup(
    packages=setuptools.find_namespace_packages(include=['seeq.sdk', 'seeq.sdk.*']),
    include_package_data=True,
    zip_safe=False,
    # A bug exists in setuptools where `license-files` is incorrectly marked as dynamic. Rely on `license` in
    # pyproject.toml until https://github.com/pypa/setuptools/issues/4960 is fixed.
    license_files=[],
)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class ModelsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def apply_model(self, **kwargs):
        """
        Apply a model once by providing inputs to the model's features. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.apply_model(body=body_value, model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelInitialApplicationInputV1 body: (required)
        :param str model_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.apply_model_with_http_info(**kwargs)
        else:
            (data) = self.apply_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def apply_model_with_http_info(self, **kwargs):
        """
        Apply a model once by providing inputs to the model's features. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.apply_model_with_http_info(body=body_value, model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelInitialApplicationInputV1 body: (required)
        :param str model_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """

        all_params = ['body', 'model_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apply_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `apply_model`")
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `apply_model`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}/instances', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def apply_model_to_table(self, **kwargs):
        """
        Apply a model to a table definition and recompute the newly-added columns. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.apply_model_to_table(body=body_value, model_id=model_id_value, table_definition_id=table_definition_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TableModelApplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str table_definition_id: (required)
        :return: ModelTableApplicationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.apply_model_to_table_with_http_info(**kwargs)
        else:
            (data) = self.apply_model_to_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def apply_model_to_table_with_http_info(self, **kwargs):
        """
        Apply a model to a table definition and recompute the newly-added columns. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.apply_model_to_table_with_http_info(body=body_value, model_id=model_id_value, table_definition_id=table_definition_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TableModelApplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str table_definition_id: (required)
        :return: ModelTableApplicationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationOutputV1
        """

        all_params = ['body', 'model_id', 'table_definition_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apply_model_to_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `apply_model_to_table`")
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `apply_model_to_table`")
        # verify the required parameter 'table_definition_id' is set
        if ('table_definition_id' not in params) or (params['table_definition_id'] is None):
            raise ValueError("Missing the required parameter `table_definition_id` when calling `apply_model_to_table`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']
        if 'table_definition_id' in params:
            path_params['tableDefinitionId'] = params['table_definition_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}/table-application/{tableDefinitionId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelTableApplicationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def archive_model(self, **kwargs):
        """
        Archive a model by its ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_model(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the model to archive (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_model_with_http_info(**kwargs)
        else:
            (data) = self.archive_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def archive_model_with_http_info(self, **kwargs):
        """
        Archive a model by its ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_model_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the model to archive (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_model`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ArchiveOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model(self, **kwargs):
        """
        Create a new model. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_model_with_http_info(**kwargs)
        else:
            (data) = self.create_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model_with_http_info(self, **kwargs):
        """
        Create a new model. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_model`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model_from_items(self, **kwargs):
        """
        Create a new model from reference items. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model_from_items(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelFromIdsInputV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_model_from_items_with_http_info(**kwargs)
        else:
            (data) = self.create_model_from_items_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model_from_items_with_http_info(self, **kwargs):
        """
        Create a new model from reference items. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model_from_items_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelFromIdsInputV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_model_from_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_model_from_items`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/from-items', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model_from_table_column_definitions(self, **kwargs):
        """
        Create a new model from reference column definitions. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model_from_table_column_definitions(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelFromIdsInputV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_model_from_table_column_definitions_with_http_info(**kwargs)
        else:
            (data) = self.create_model_from_table_column_definitions_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_model_from_table_column_definitions_with_http_info(self, **kwargs):
        """
        Create a new model from reference column definitions. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_model_from_table_column_definitions_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelFromIdsInputV1 body: (required)
        :return: ModelV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_model_from_table_column_definitions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_model_from_table_column_definitions`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/from-table-column-definitions', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def edit_model(self, **kwargs):
        """
        Edit a model by ID. The full model must be provided. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.edit_model(body=body_value, model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelV1 body: (required)
        :param str model_id: (required)
        :return: ModelOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.edit_model_with_http_info(**kwargs)
        else:
            (data) = self.edit_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def edit_model_with_http_info(self, **kwargs):
        """
        Edit a model by ID. The full model must be provided. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.edit_model_with_http_info(body=body_value, model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelV1 body: (required)
        :param str model_id: (required)
        :return: ModelOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputV1
        """

        all_params = ['body', 'model_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `edit_model`")
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `edit_model`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def generate_column_model(self, **kwargs):
        """
        Generates a list of independent and dependent column definitions from a list of items. The independent column definitions do not rely on other columns, while the dependent column definitions do. This can be used to create a model table from calculations. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.generate_column_model(body=body_value, scoped_to=scoped_to_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ColumnModelInputV1 body: (required)
        :param str scoped_to: The ID of the Workbook that the formula creator column rules will be scoped to (required)
        :return: ColumnModelOutput
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ColumnModelOutput
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.generate_column_model_with_http_info(**kwargs)
        else:
            (data) = self.generate_column_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def generate_column_model_with_http_info(self, **kwargs):
        """
        Generates a list of independent and dependent column definitions from a list of items. The independent column definitions do not rely on other columns, while the dependent column definitions do. This can be used to create a model table from calculations. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.generate_column_model_with_http_info(body=body_value, scoped_to=scoped_to_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ColumnModelInputV1 body: (required)
        :param str scoped_to: The ID of the Workbook that the formula creator column rules will be scoped to (required)
        :return: ColumnModelOutput
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ColumnModelOutput
        """

        all_params = ['body', 'scoped_to']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_column_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `generate_column_model`")
        # verify the required parameter 'scoped_to' is set
        if ('scoped_to' not in params) or (params['scoped_to'] is None):
            raise ValueError("Missing the required parameter `scoped_to` when calling `generate_column_model`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scoped_to' in params:
            query_params.append(('scopedTo', params['scoped_to']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/modelData', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ColumnModelOutput'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instance(self, **kwargs):
        """
        Fetch model instance by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instance(instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str instance_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_instance_with_http_info(**kwargs)
        else:
            (data) = self.get_instance_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instance_with_http_info(self, **kwargs):
        """
        Fetch model instance by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instance_with_http_info(instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str instance_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """

        all_params = ['instance_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params) or (params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `get_instance`")


        collection_formats = {}

        path_params = {}
        if 'instance_id' in params:
            path_params['instanceId'] = params['instance_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/instances/{instanceId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instances_for_model(self, **kwargs):
        """
        Fetch model instances for model ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instances_for_model(model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str model_id: (required)
        :param int offset: The pagination offset, the index of the first model instance that will be returned in this page of results
        :param int limit: The pagination limit, the total number of model instances that will be returned in this page of results
        :return: InstanceOutputPaginatedListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputPaginatedListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_instances_for_model_with_http_info(**kwargs)
        else:
            (data) = self.get_instances_for_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instances_for_model_with_http_info(self, **kwargs):
        """
        Fetch model instances for model ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instances_for_model_with_http_info(model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str model_id: (required)
        :param int offset: The pagination offset, the index of the first model instance that will be returned in this page of results
        :param int limit: The pagination limit, the total number of model instances that will be returned in this page of results
        :return: InstanceOutputPaginatedListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputPaginatedListV1
        """

        all_params = ['model_id', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instances_for_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_instances_for_model`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}/instances', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceOutputPaginatedListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instances_for_table(self, **kwargs):
        """
        Fetch model instances for table definition ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instances_for_table(table_definition_id=table_definition_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str table_definition_id: (required)
        :param int offset: The pagination offset, the index of the first model instance that will be returned in this page of results
        :param int limit: The pagination limit, the total number of model instances that will be returned in this page of results
        :return: InstanceOutputPaginatedListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputPaginatedListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_instances_for_table_with_http_info(**kwargs)
        else:
            (data) = self.get_instances_for_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_instances_for_table_with_http_info(self, **kwargs):
        """
        Fetch model instances for table definition ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_instances_for_table_with_http_info(table_definition_id=table_definition_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str table_definition_id: (required)
        :param int offset: The pagination offset, the index of the first model instance that will be returned in this page of results
        :param int limit: The pagination limit, the total number of model instances that will be returned in this page of results
        :return: InstanceOutputPaginatedListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputPaginatedListV1
        """

        all_params = ['table_definition_id', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instances_for_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'table_definition_id' is set
        if ('table_definition_id' not in params) or (params['table_definition_id'] is None):
            raise ValueError("Missing the required parameter `table_definition_id` when calling `get_instances_for_table`")


        collection_formats = {}

        path_params = {}
        if 'table_definition_id' in params:
            path_params['tableDefinitionId'] = params['table_definition_id']

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/instances/table/{tableDefinitionId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceOutputPaginatedListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_model(self, **kwargs):
        """
        Fetch a model by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_model(model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str model_id: (required)
        :return: ModelOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_model_with_http_info(**kwargs)
        else:
            (data) = self.get_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_model_with_http_info(self, **kwargs):
        """
        Fetch a model by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_model_with_http_info(model_id=model_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str model_id: (required)
        :return: ModelOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputV1
        """

        all_params = ['model_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_model`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_models(self, **kwargs):
        """
        Get a list of models. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_models(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of models that will be returned in this page of results
        :return: ModelOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_models_with_http_info(**kwargs)
        else:
            (data) = self.get_models_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_models_with_http_info(self, **kwargs):
        """
        Get a list of models. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_models_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of models that will be returned in this page of results
        :return: ModelOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelOutputListV1
        """

        all_params = ['offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_models" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_table_definition_model_applications(self, **kwargs):
        """
        Get the models applied to a given table definition. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_table_definition_model_applications(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the table definition (required)
        :return: ModelTableApplicationsOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationsOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_table_definition_model_applications_with_http_info(**kwargs)
        else:
            (data) = self.get_table_definition_model_applications_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_table_definition_model_applications_with_http_info(self, **kwargs):
        """
        Get the models applied to a given table definition. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_table_definition_model_applications_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the table definition (required)
        :return: ModelTableApplicationsOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationsOutputListV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_table_definition_model_applications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_table_definition_model_applications`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{id}/model-applications', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelTableApplicationsOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def reapply_model(self, **kwargs):
        """
        Reapply a model once by providing inputs to the model's features. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reapply_model(body=body_value, model_id=model_id_value, instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelReapplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str instance_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.reapply_model_with_http_info(**kwargs)
        else:
            (data) = self.reapply_model_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def reapply_model_with_http_info(self, **kwargs):
        """
        Reapply a model once by providing inputs to the model's features. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reapply_model_with_http_info(body=body_value, model_id=model_id_value, instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelReapplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str instance_id: (required)
        :return: InstanceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceOutputV1
        """

        all_params = ['body', 'model_id', 'instance_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reapply_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `reapply_model`")
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `reapply_model`")
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params) or (params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `reapply_model`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']
        if 'instance_id' in params:
            path_params['instanceId'] = params['instance_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}/instances/{instanceId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def reapply_model_to_table(self, **kwargs):
        """
        Reapply a model to a table definition and recompute the results using the updated inputs. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reapply_model_to_table(body=body_value, model_id=model_id_value, table_definition_id=table_definition_id_value, application_id=application_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TableModelApplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str table_definition_id: (required)
        :param str application_id: (required)
        :return: ModelTableApplicationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.reapply_model_to_table_with_http_info(**kwargs)
        else:
            (data) = self.reapply_model_to_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def reapply_model_to_table_with_http_info(self, **kwargs):
        """
        Reapply a model to a table definition and recompute the results using the updated inputs. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reapply_model_to_table_with_http_info(body=body_value, model_id=model_id_value, table_definition_id=table_definition_id_value, application_id=application_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TableModelApplicationInputV1 body: (required)
        :param str model_id: (required)
        :param str table_definition_id: (required)
        :param str application_id: (required)
        :return: ModelTableApplicationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelTableApplicationOutputV1
        """

        all_params = ['body', 'model_id', 'table_definition_id', 'application_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reapply_model_to_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `reapply_model_to_table`")
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params) or (params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `reapply_model_to_table`")
        # verify the required parameter 'table_definition_id' is set
        if ('table_definition_id' not in params) or (params['table_definition_id'] is None):
            raise ValueError("Missing the required parameter `table_definition_id` when calling `reapply_model_to_table`")
        # verify the required parameter 'application_id' is set
        if ('application_id' not in params) or (params['application_id'] is None):
            raise ValueError("Missing the required parameter `application_id` when calling `reapply_model_to_table`")


        collection_formats = {}

        path_params = {}
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']
        if 'table_definition_id' in params:
            path_params['tableDefinitionId'] = params['table_definition_id']
        if 'application_id' in params:
            path_params['applicationId'] = params['application_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/{modelId}/table-application/{tableDefinitionId}/{applicationId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ModelTableApplicationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def retire_application(self, **kwargs):
        """
        Retire a model table application by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.retire_application(application_id=application_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str application_id: (required)
        :return: TableApplicationRetiredOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TableApplicationRetiredOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.retire_application_with_http_info(**kwargs)
        else:
            (data) = self.retire_application_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def retire_application_with_http_info(self, **kwargs):
        """
        Retire a model table application by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.retire_application_with_http_info(application_id=application_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str application_id: (required)
        :return: TableApplicationRetiredOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TableApplicationRetiredOutputV1
        """

        all_params = ['application_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retire_application" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'application_id' is set
        if ('application_id' not in params) or (params['application_id'] is None):
            raise ValueError("Missing the required parameter `application_id` when calling `retire_application`")


        collection_formats = {}

        path_params = {}
        if 'application_id' in params:
            path_params['applicationId'] = params['application_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/applications/{applicationId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'TableApplicationRetiredOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def retire_instance(self, **kwargs):
        """
        Retire a model instance by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.retire_instance(instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str instance_id: (required)
        :return: InstanceRetiredOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceRetiredOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.retire_instance_with_http_info(**kwargs)
        else:
            (data) = self.retire_instance_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def retire_instance_with_http_info(self, **kwargs):
        """
        Retire a model instance by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.retire_instance_with_http_info(instance_id=instance_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str instance_id: (required)
        :return: InstanceRetiredOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InstanceRetiredOutputV1
        """

        all_params = ['instance_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retire_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instance_id' is set
        if ('instance_id' not in params) or (params['instance_id'] is None):
            raise ValueError("Missing the required parameter `instance_id` when calling `retire_instance`")


        collection_formats = {}

        path_params = {}
        if 'instance_id' in params:
            path_params['instanceId'] = params['instance_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/models/instances/{instanceId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'InstanceRetiredOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
